@@ -1,5 +1,6 @@
+from .__main__ import console_entry_point
+
 __all__ = [
     'search',
     'download',
-    'patches'
-]
\ No newline at end of file
+]
