@@ -1,29 +1,26 @@
+from typing import List
+
 from spotdl.search.provider import search_and_get_best_match
 from spotdl.search.spotifyClient import get_spotify_client
 
-from os.path import join
-
-from json import dumps as convert_dict_to_json, loads as convert_json_to_dict
-
-from typing import List
 
 class SongObj():
-    #! This can be accessed as songObj.searchProvider. songObj acts like a namespace
-    #! it allows us a convenient way of setting a search provider without using globals
+    # ! This can be accessed as songObj.searchProvider. songObj acts like a namespace
+    # ! it allows us a convenient way of setting a search provider without using globals
     searchProvider = search_and_get_best_match
 
-    #====================
-    #=== Constructors ===
-    #====================
+    # ====================
+    # === Constructors ===
+    # ====================
     def __init__(self, rawTrackMeta, rawAlbumMeta, rawArtistMeta, youtubeLink):
-        self. __rawTrackMeta = rawTrackMeta
-        self.__rawAlbumMeta  = rawArtistMeta
+        self.__rawTrackMeta = rawTrackMeta
+        self.__rawAlbumMeta = rawArtistMeta
         self.__rawArtistMeta = rawArtistMeta
-        self.__youtubeLink   = youtubeLink
+        self.__youtubeLink = youtubeLink
 
     #! constructors here are a bit mucky, there are two different constructors for two
     #! different use cases, hence the actual __init__ function does not exist
-    
+
     #! Note, since the following are class methods, an instance of songObj is initialized
     #! and passed to them
     @classmethod
@@ -70,13 +67,11 @@ class SongObj():
             duration
         )
 
-        youtubeLink = youtubeLink
-
         return  cls(
             rawTrackMeta, rawAlbumMeta,
             rawArtistMeta, youtubeLink
         )
-        
+
     @classmethod
     def from_dump(cls, dataDump: dict):
         rawTrackMeta  = dataDump['rawTrackMeta']
@@ -103,15 +98,15 @@ class SongObj():
         return self.__youtubeLink
 
     #! Song Details:
-    
+
     #! 1. Name
     def get_song_name(self) -> str:
         ''''
         returns songs's name.
         '''
-        
+
         return self.__rawTrackMeta['name']
-    
+
     #! 2. Track Number
     def get_track_number(self) -> int:
         '''
@@ -120,7 +115,7 @@ class SongObj():
         '''
 
         return self.__rawTrackMeta['track_number']
-    
+
     #! 3. Genres
     def get_genres(self) -> List[str]:
         '''
@@ -130,7 +125,7 @@ class SongObj():
         '''
 
         return self.__rawAlbumMeta['genres'] + self.__rawArtistMeta['genres']
-    
+
     #! 4. Duration
     def get_duration(self) -> float:
         '''
@@ -138,7 +133,7 @@ class SongObj():
         '''
 
         return round(self.__rawTrackMeta['duration_ms'] / 1000, ndigits = 3)
-    
+
     #! 5. All involved artists
     def get_contributing_artists(self) -> List[str]:
         '''
@@ -147,7 +142,7 @@ class SongObj():
         '''
 
         # we get rid of artist name that are in the song title so
-        # naming the song would be as easy as 
+        # naming the song would be as easy as
         # $contributingArtists + songName.mp3, we would want to end up with
         # 'Jetta, Mastubs - I'd love to change the world (Mastubs remix).mp3'
         # as a song name, it's dumb.
@@ -156,11 +151,11 @@ class SongObj():
 
         for artist in self.__rawTrackMeta['artists']:
             contributingArtists.append(artist['name'])
-        
+
         return contributingArtists
 
     #! Album Details:
-    
+
     #! 1. Name
     def get_album_name(self) -> str:
         '''
@@ -168,7 +163,7 @@ class SongObj():
         '''
 
         return self.__rawTrackMeta['album']['name']
-    
+
     #! 2. All involved artist
     def get_album_artists(self) -> List[str]:
         '''
@@ -181,9 +176,9 @@ class SongObj():
 
         for artist in self.__rawTrackMeta['album']['artists']:
             albumArtists.append(artist['name'])
-        
+
         return albumArtists
-    
+
     #! 3. Release Year/Date
     def get_album_release(self) -> str:
         '''
@@ -191,9 +186,9 @@ class SongObj():
         '''
 
         return self.__rawTrackMeta['album']['release_date']
-    
+
     #! Utilities for genuine use and also for metadata freaks:
-    
+
     #! 1. Album Art URL
     def get_album_cover_url(self) -> str:
         '''
@@ -201,7 +196,7 @@ class SongObj():
         '''
 
         return self.__rawTrackMeta['album']['images'][0]['url']
-    
+
     #! 2. All the details the spotify-api can provide
     def get_data_dump(self) -> dict:
         '''
@@ -210,7 +205,7 @@ class SongObj():
             - rawTrackMeta      spotify-api track details
             - rawAlbumMeta      spotify-api song's album details
             - rawArtistMeta     spotify-api song's artist details
-        
+
         Avoid using this function, it is implemented here only for those super
         rare occasions where there is a need to look up other details. Why
         have to look it up seperately when it's already been looked up once?
@@ -223,4 +218,4 @@ class SongObj():
             'rawTrackMeta' : self.__rawTrackMeta,
             'rawAlbumMeta' : self.__rawAlbumMeta,
             'rawArtistMeta': self.__rawArtistMeta
-        }
\ No newline at end of file
+        }
